#[non_exhaustive]pub enum TypeInfo {
String,
Integer,
Number,
Boolean,
Array(Box<FieldType>),
Map(Box<FieldType>),
Object(String),
Enum {
values: Vec<String>,
underlying: Box<FieldType>,
},
Any,
}Expand description
Platform-independent field type for code generation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl FieldType
impl FieldType
Sourcepub fn is_primitive(&self) -> bool
pub fn is_primitive(&self) -> bool
Check if this is a primitive type.
Sourcepub fn is_collection(&self) -> bool
pub fn is_collection(&self) -> bool
Check if this is a collection type (Array or Map).
Sourcepub fn inner_type(&self) -> Option<&FieldType>
pub fn inner_type(&self) -> Option<&FieldType>
Get the inner type for Array or Map.
Sourcepub fn enum_values(&self) -> Option<&[String]>
pub fn enum_values(&self) -> Option<&[String]>
Get enum values if this is an Enum type.
Sourcepub fn object_name(&self) -> Option<&str>
pub fn object_name(&self) -> Option<&str>
Returns the object name if this is an Object type.