pub struct SchemaDiff {
pub added: Vec<String>,
pub removed: Vec<String>,
pub changed: Vec<FieldChange>,
}Expand description
Result of diffing two schemas by field name.
Fields
added: Vec<String>Field names present in schema B but absent from schema A.
removed: Vec<String>Field names present in schema A but absent from schema B.
changed: Vec<FieldChange>Fields present in both but with different type or required status.